Theo Bell Invitational Montreal, Quebec September 8th 2001 3R+F 21 players Hugues Bertrand http://web.archive.org/web/20030118091821fw_/http://www.oricom.ca/melkor/vekn_quebec/lots2r.htm Deck Name: GAGNER SANS DOMINATE NI PRESENCE (Montreal version) Description: This is the winning deck of Hugues Bertrand for the tournament Theo Bell Invitational, held in Montreal on September 8, 2001. It's a new version of the deck he played at the Lure of the Serpent tournament. Note: The name of the deck can be translated something like this: "Winning without Dominate and Presence" Crypt (12 cards, min=23, max=38, avg=7.83) ------------------------------------------ 2x Sheldon, Lord of the Clog 9 ANI AUS OBF POT for justicar Nosferatu:1 2x Selma the Repugnant 8 OBF POT ani for prince Nosferatu:1 2x Nikolaus Vermeulen 7 POT ani for obf prince Nosferatu:2 1x Angus the Unruled 10 ANI PRO cel for pot justicar Gangrel:1 1x Ulugh Beg, The Watcher 10 AUS DOM THA cel for pot justicar Tremere:1 1x Suhailah 9 FOR OBF pot ser prince Ventrue:2 1x Emerson Bridges 8 DOM FOR PRE pot prince Ventrue:1 1x Calebros, The Martyr 5 ANI obf pot prince Nosferatu:2 1x Jimmy Dunn 4 CEL POT for Pander:2 -- not sure why Library (90 cards) Master (12) 1x Giant's Blood 1x Golconda: Inner Peace 7x Minion Tap 3x Temptation of Greater Power Action (7) 7x Fifth Tradition: Hospitality Political Action (20) 3x Archon 2x First Tradition: The Masquerade 3x Kindred Restructure 8x Kine Resources Contested 1x Nosferatu Justicar -- pour Calebros! 3x Rumors of Gehenna Action Modifier (12) 2x Forgotten Labyrinth 5x Freak Drive 5x Lost in Crowds Reaction (7) 7x Second Tradition: Domain Combat (32) 4x Amaranth 1x Burning Wrath 6x Disarm 7x Immortal Grapple 8x Skin of Steel 6x Torn Signpost